@@ -42,35 +42,40 @@ static apc_iterator_item_t* apc_iterator_item_ctor(apc_iterator_t *iterator, apc
 
 	item->key = estrndup(
 		slot->key.str, slot->key.len);
-	item->key_len = slot->key.len;	
+	item->key_len = slot->key.len;
+	
+	/* for bc, in any mode */
+	if (APC_ITER_TYPE & iterator->format) {
+		add_assoc_string(item->value, "type", "user", 1);
+    }
 	
     if (APC_ITER_KEY & iterator->format) {
         add_assoc_stringl(item->value, "key", item->key, (item->key_len - 1), 1);
     }
 
     if (APC_ITER_VALUE & iterator->format) {
-        ctxt.pool = apc_pool_create(APC_UNPOOL, apc_php_malloc, apc_php_free, NULL, NULL TSRMLS_CC);
-        ctxt.copy = APC_COPY_OUT;
-
+    	apc_cache_make_context(
+    		apc_user_cache, &ctxt, APC_CONTEXT_NOSHARE, APC_UNPOOL, APC_COPY_OUT, 0 TSRMLS_CC);
+    	
         MAKE_STD_ZVAL(zvalue);
         apc_cache_fetch_zval(&ctxt, zvalue, slot->value->val TSRMLS_CC);
         apc_pool_destroy(ctxt.pool TSRMLS_CC);
         add_assoc_zval(item->value, "value", zvalue);
     }
     if (APC_ITER_NUM_HITS & iterator->format) {
-        add_assoc_long(item->value, "nhits", slot->nhits);
+        add_assoc_long(item->value, "num_hits", slot->nhits);
     }
     if (APC_ITER_MTIME & iterator->format) {
-        add_assoc_long(item->value, "mtime", slot->key.mtime);
+        add_assoc_long(item->value, "modified_time", slot->key.mtime);
     }
     if (APC_ITER_CTIME & iterator->format) {
-        add_assoc_long(item->value, "ctime", slot->ctime);
+        add_assoc_long(item->value, "creation_time", slot->ctime);
     }
     if (APC_ITER_DTIME & iterator->format) {
-        add_assoc_long(item->value, "dtime", slot->dtime);
+        add_assoc_long(item->value, "deletion_time", slot->dtime);
     }
     if (APC_ITER_ATIME & iterator->format) {
-        add_assoc_long(item->value, "atime", slot->atime);
+        add_assoc_long(item->value, "access_time", slot->atime);
     }
     if (APC_ITER_REFCOUNT & iterator->format) {
         add_assoc_long(item->value, "ref_count", slot->value->ref_count);
@@ -610,7 +615,7 @@ int apc_iterator_init(int module_number TSRMLS_DC) {
 
     REGISTER_LONG_CONSTANT("APC_LIST_ACTIVE", APC_LIST_ACTIVE, CONST_PERSISTENT | CONST_CS);
     REGISTER_LONG_CONSTANT("APC_LIST_DELETED", APC_LIST_DELETED, CONST_PERSISTENT | CONST_CS);
-
+	REGISTER_LONG_CONSTANT("APC_ITER_TYPE", APC_ITER_TYPE, CONST_PERSISTENT | CONST_CS);
     REGISTER_LONG_CONSTANT("APC_ITER_KEY", APC_ITER_KEY, CONST_PERSISTENT | CONST_CS);
     REGISTER_LONG_CONSTANT("APC_ITER_VALUE", APC_ITER_VALUE, CONST_PERSISTENT | CONST_CS);
     REGISTER_LONG_CONSTANT("APC_ITER_NUM_HITS", APC_ITER_NUM_HITS, CONST_PERSISTENT | CONST_CS);
